# -*- coding:utf-8 -*-
import sys
import os
__author__ = 'allen yang'
__version__ = '0.1.0'



from .base.event import (get_scrape_report,
                        get_scrape_transaction,
                        get_strategy)


#!/usr/bin/env python
# coding=utf-8
from setuptools import setup

setup(
    name='wencai',
    version='0.1.1',
    author='allen yang',
    author_email='allenyzx@163.com',
    url='https://upload.pypi.org/allenyzx/',
    description='this is a wencai crawler to get message',
    packages=['wencai'],
    install_requires=[
        "beautifulsoup4",
        "pandas",
        "requests"
    ],
    license='MIT',
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Indexing",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.5",
    ],
)